@@ -4,7 +4,7 @@ injectable.
 """
 # sphinx-start
 from examples import Example
-from injectable import injectable, InjectionContainer, autowired, Autowired
+from injectable import injectable, autowired, Autowired, load_injection_container
 
 
 @injectable  # make examples also injectable for testing
@@ -21,6 +21,6 @@ class Factory(Example):
 
 
 if __name__ == "__main__":
-    InjectionContainer.load()
+    load_injection_container()
     example = Factory()
     example.run()
