@@ -1,4 +1,5 @@
 import os
+import warnings
 from importlib.util import module_from_spec, spec_from_file_location
 from typing import Dict, Optional, Callable
 from typing import Set
@@ -7,7 +8,8 @@ from pycollect import PythonFileCollector, find_module_name
 
 from injectable.container.injectable import Injectable
 from injectable.container.namespace import Namespace
-from injectable.utils import get_caller_filepath
+from injectable.common_utils import get_caller_filepath
+from injectable.constants import DEFAULT_NAMESPACE
 
 
 class InjectionContainer:
@@ -15,22 +17,28 @@ class InjectionContainer:
     InjectionContainer globally manages injection namespaces and the respective
     injectables registries.
 
-    Invoking :meth:`load` is the only necessary action before injecting dependencies.
-    Attempting to call an autowired function before invoking :meth:`load` will raise an
-    :class:`InjectionContainerNotLoadedError
-    <injectable.errors.InjectionContainerNotLoadedError>`.
+    This class shouldn't be used directly and will be removed from the injectable's
+    public API in the future.
+
+    Invoking :func:`load_injection_container` is the only necessary action before
+    injecting dependencies. Attempting to call an autowired function before invoking
+    :func:`load_injection_container` will log a warning indicating that the injection
+    container is empty.
 
     This class is not meant to be instantiated and will raise an error if instantiation
     is attempted.
+
+    .. deprecated:: 3.4.0
+        This class will be removed from the public API in the future.
     """
 
+    LOADING_DEFAULT_NAMESPACE: Optional[str] = None
     LOADING_FILEPATH: Optional[str] = None
     LOADED_FILEPATHS: Set[str] = set()
     NAMESPACES: Dict[str, Namespace] = {}
-    DEFAULT_NAMESPACE: str
 
     def __new__(cls):
-        raise TypeError("InjectionContainer must not be instantiated")
+        raise NotImplementedError("InjectionContainer must not be instantiated")
 
     @classmethod
     def load(
@@ -40,32 +48,46 @@ class InjectionContainer:
         Loads injectables under the search path to the :class:`InjectionContainer`
         under the designated namespaces.
 
-        This method will not scan any file more than once regardless of being
-        called successively. Multiple invocations to different search paths will
-        add found injectables to the :class:`InjectionContainer` without clearing
-        previously found ones.
-
         :param search_path: (optional) path under which to search for injectables. Can
                 be either a relative or absolute path. Defaults to the caller's file
                 directory.
         :param default_namespace: (optional) designated namespace for registering
                 injectables which does not explicitly request to be addressed in a
-                specific namespace. Defaults to '_GLOBAL'.
+                specific namespace. Defaults to
+                :const:`injectable.constants.DEFAULT_NAMESPACE`.
 
         Usage::
 
           >>> from injectable import InjectionContainer
-          >>>
           >>> InjectionContainer.load()
+
+        .. note::
+
+            This method will not scan any file more than once regardless of being
+            called successively. Multiple invocations to different search paths will
+            add found injectables to the :class:`InjectionContainer` without clearing
+            previously found ones.
+
+        .. deprecated:: 3.4.0
+            This method will be removed from the public API in the future. Use
+            :func:`load_injection_container` instead.
         """
-        cls.DEFAULT_NAMESPACE = default_namespace or "_GLOBAL"
+        warnings.warn(
+            "Using 'load' directly from the 'InjectionContainer' is deprecated."
+            " Use 'load_injection_container' instead. This class will be removed from"
+            " the injectable's public API in the future.",
+            DeprecationWarning,
+            2,
+        )
+        cls.LOADING_DEFAULT_NAMESPACE = default_namespace or DEFAULT_NAMESPACE
         cls.NAMESPACES[default_namespace] = Namespace()
         if search_path is None:
             search_path = os.path.dirname(get_caller_filepath())
         elif not os.path.isabs(search_path):
             caller_path = os.path.dirname(get_caller_filepath())
-            search_path = os.path.abspath(os.path.join(caller_path, search_path))
+            search_path = os.path.normpath(os.path.join(caller_path, search_path))
         cls._link_dependencies(search_path)
+        cls.LOADING_DEFAULT_NAMESPACE = None
 
     @classmethod
     def _register_injectable(
@@ -80,7 +102,9 @@ class InjectionContainer:
     ):
         unique_id = f"{klass.__qualname__}@{filepath}"
         injectable = Injectable(klass, unique_id, primary, group, singleton)
-        namespace_entry = cls._get_namespace_entry(namespace or cls.DEFAULT_NAMESPACE)
+        namespace_entry = cls._get_namespace_entry(
+            namespace or cls.LOADING_DEFAULT_NAMESPACE
+        )
         namespace_entry.register_injectable(injectable, klass, qualifier)
 
     @classmethod
@@ -88,7 +112,7 @@ class InjectionContainer:
         cls,
         factory: Callable,
         filepath: str,
-        dependency: Optional[type],
+        dependency: Optional[type] = None,
         qualifier: str = None,
         primary: bool = False,
         namespace: str = None,
@@ -97,7 +121,9 @@ class InjectionContainer:
     ):
         unique_id = f"{factory.__qualname__}@{filepath}"
         injectable = Injectable(factory, unique_id, primary, group, singleton)
-        namespace_entry = cls._get_namespace_entry(namespace or cls.DEFAULT_NAMESPACE)
+        namespace_entry = cls._get_namespace_entry(
+            namespace or cls.LOADING_DEFAULT_NAMESPACE
+        )
         namespace_entry.register_injectable(injectable, dependency, qualifier)
 
     @classmethod
@@ -115,10 +141,25 @@ class InjectionContainer:
             if file.path in cls.LOADED_FILEPATHS:
                 continue
             cls.LOADING_FILEPATH = file.path
-            cls._register_injectables(file)
+            cls._load_file(file)
             cls.LOADED_FILEPATHS.add(file.path)
             cls.LOADING_FILEPATH = None
 
+    @classmethod
+    def load_dependencies_from(cls, absolute_search_path: str, default_namespace: str):
+        files = cls._collect_python_files(absolute_search_path)
+        cls.LOADING_DEFAULT_NAMESPACE = default_namespace
+        for file in files:
+            if not cls._contains_injectables(file):
+                continue
+            if file.path in cls.LOADED_FILEPATHS:
+                continue
+            cls.LOADING_FILEPATH = file.path
+            cls._load_file(file)
+            cls.LOADED_FILEPATHS.add(file.path)
+            cls.LOADING_FILEPATH = None
+        cls.LOADING_DEFAULT_NAMESPACE = None
+
     @classmethod
     def _collect_python_files(cls, search_path) -> Set[os.DirEntry]:
         collector = PythonFileCollector()
@@ -128,7 +169,7 @@ class InjectionContainer:
     def _contains_injectables(cls, file_entry: os.DirEntry) -> bool:
         with open(file_entry) as file:
             source = file.read()
-        # TODO: Evaluate the use of ast.parse for this
+        # TODO: Consider the use of ast.parse for this
         return any(
             usage in source
             for usage in [
@@ -140,7 +181,7 @@ class InjectionContainer:
         )
 
     @classmethod
-    def _register_injectables(cls, file: os.DirEntry):
+    def _load_file(cls, file: os.DirEntry):
         module_name = find_module_name(file)
         spec = spec_from_file_location(module_name, file.path)
         module = module_from_spec(spec)
